@@ -9,5 +9,5 @@ class BaseExceptions(Exception):
     MESSAGE = "Error base class"
 
 
-class NotStrDirectory(BaseExceptions):
+class NotSetDirectory(BaseExceptions):
     MESSAGE = "未设置项目目录"
